==> desktop_ui-0.0.3.tar.gz: lib/components/icon.dart <==
// 自定义图标
import 'package:desktop_ui/constants.dart';
import 'package:flutter/material.dart';

/// 自定义图标-self desktop icon
class EasyIcon extends StatelessWidget {
  const EasyIcon(
    this.icon, {
    Key? key,
    this.color = iBlack,
    this.size,
    this.opacity,
    this.semanticLabel,
  }) : super(key: key);

  /// 图标
  final IconData? icon;

  /// 图标大小，默认为：20.0
  final double? size;

  /// 图标透明度，默认为：1.0
  final double? opacity;

  /// 图标颜色
  final Color? color;

  /// 图标语义描述信息，无障碍信息
  final String? semanticLabel;

  @override
  Widget build(BuildContext context) {
    final double? iconSize = size ?? iIconSize;
    // 不存在，返回固定大小的一块区域
    if (icon == null) {
      return Semantics(
        label: semanticLabel,
        child: SizedBox(width: iconSize, height: iconSize),
      );
    }
    final double iconOpacity = opacity ?? 1.0;
    Color iconColor = color ?? iBlack;
    if (iconOpacity != 1.0) {
      iconColor = iconColor.withOpacity(iconColor.opacity * iconOpacity);
    }

    Widget iconWidget = RichText(
      overflow: TextOverflow.visible,
      text: TextSpan(
        text: String.fromCharCode(icon!.codePoint),
        style: TextStyle(
          inherit: false,
          color: iconColor,
          fontSize: iconSize,
          fontFamily: icon!.fontFamily,
          package: 'desktop_ui',
        ),
      ),
    );

    return Semantics(
      label: semanticLabel,
      child: ExcludeSemantics(
        child: IntrinsicWidth(
          child: IntrinsicHeight(
            child: Center(
              child: iconWidget,
            ),
          ),
        ),
      ),
    );
  }
}

/// 支持的图标-support icon
class EasyIconData {
  static const IconData more = IconData(0xe6ae, fontFamily: 'IconFont');
  static const IconData pad = IconData(0xe6af, fontFamily: 'IconFont');
  static const IconData operation = IconData(0xe6b0, fontFamily: 'IconFont');
  static const IconData play = IconData(0xe6b1, fontFamily: 'IconFont');
  static const IconData print = IconData(0xe6b2, fontFamily: 'IconFont');
  static const IconData mobilePhone = IconData(0xe6b3, fontFamily: 'IconFont');
  static const IconData minus = IconData(0xe6b4, fontFamily: 'IconFont');
  static const IconData navigation = IconData(0xe6b5, fontFamily: 'IconFont');
  static const IconData pdf = IconData(0xe6b6, fontFamily: 'IconFont');
  static const IconData prompt = IconData(0xe6b7, fontFamily: 'IconFont');
  static const IconData move = IconData(0xe6b8, fontFamily: 'IconFont');
  static const IconData refresh = IconData(0xe6b9, fontFamily: 'IconFont');
  static const IconData picture = IconData(0xe6ba, fontFamily: 'IconFont');
  static const IconData pin = IconData(0xe6bb, fontFamily: 'IconFont');
  static const IconData save = IconData(0xe6bc, fontFamily: 'IconFont');
  static const IconData search = IconData(0xe6bd, fontFamily: 'IconFont');
  static const IconData share = IconData(0xe6be, fontFamily: 'IconFont');
  static const IconData scanning = IconData(0xe6bf, fontFamily: 'IconFont');
  static const IconData security = IconData(0xe6c0, fontFamily: 'IconFont');
  static const IconData signOut = IconData(0xe6c1, fontFamily: 'IconFont');
  static const IconData select = IconData(0xe6c2, fontFamily: 'IconFont');
  static const IconData stop = IconData(0xe6c3, fontFamily: 'IconFont');
  static const IconData success = IconData(0xe6c4, fontFamily: 'IconFont');
  static const IconData smile = IconData(0xe6c5, fontFamily: 'IconFont');
  static const IconData switchAction = IconData(0xe6c6, fontFamily: 'IconFont');
  static const IconData setting = IconData(0xe6c7, fontFamily: 'IconFont');
  static const IconData survey = IconData(0xe6c8, fontFamily: 'IconFont');
  static const IconData task = IconData(0xe6c9, fontFamily: 'IconFont');
  static const IconData skip = IconData(0xe6ca, fontFamily: 'IconFont');
  static const IconData text = IconData(0xe6cb, fontFamily: 'IconFont');
  static const IconData time = IconData(0xe6cc, fontFamily: 'IconFont');
  static const IconData telephoneOut = IconData(0xe6cd, fontFamily: 'IconFont');
  static const IconData toggleLeft = IconData(0xe6ce, fontFamily: 'IconFont');
  static const IconData toggleRight = IconData(0xe6cf, fontFamily: 'IconFont');
  static const IconData telephone = IconData(0xe6d0, fontFamily: 'IconFont');
  static const IconData top = IconData(0xe6d1, fontFamily: 'IconFont');
  static const IconData unlock = IconData(0xe6d2, fontFamily: 'IconFont');
  static const IconData user = IconData(0xe6d3, fontFamily: 'IconFont');
  static const IconData upload = IconData(0xe6d4, fontFamily: 'IconFont');
  static const IconData work = IconData(0xe6d5, fontFamily: 'IconFont');
  static const IconData training = IconData(0xe6d6, fontFamily: 'IconFont');
  static const IconData warning = IconData(0xe6d7, fontFamily: 'IconFont');
  static const IconData zoomIn = IconData(0xe6d8, fontFamily: 'IconFont');
  static const IconData zoomOut = IconData(0xe6d9, fontFamily: 'IconFont');
  static const IconData addBold = IconData(0xe6da, fontFamily: 'IconFont');
  static const IconData arrowLeftBold = IconData(0xe6db, fontFamily: 'IconFont');
  static const IconData arrowUpBold = IconData(0xe6dc, fontFamily: 'IconFont');
  static const IconData closeBold = IconData(0xe6dd, fontFamily: 'IconFont');
  static const IconData arrowDownBold = IconData(0xe6de, fontFamily: 'IconFont');
  static const IconData minusBold = IconData(0xe6df, fontFamily: 'IconFont');
  static const IconData arrowRightBold = IconData(0xe6e0, fontFamily: 'IconFont');
  static const IconData selectBold = IconData(0xe6e1, fontFamily: 'IconFont');
  static const IconData add = IconData(0xe664, fontFamily: 'IconFont');
  static const IconData addCircle = IconData(0xe665, fontFamily: 'IconFont');
  static const IconData adjust = IconData(0xe666, fontFamily: 'IconFont');
  static const IconData arrowUpCircle = IconData(0xe667, fontFamily: 'IconFont');
  static const IconData arrowRightCircle = IconData(0xe668, fontFamily: 'IconFont');
  static const IconData arrowDown = IconData(0xe669, fontFamily: 'IconFont');
  static const IconData ashbin = IconData(0xe66a, fontFamily: 'IconFont');
  static const IconData arrowRight = IconData(0xe66b, fontFamily: 'IconFont');
  static const IconData browse = IconData(0xe66c, fontFamily: 'IconFont');
  static const IconData bottom = IconData(0xe66d, fontFamily: 'IconFont');
  static const IconData back = IconData(0xe66e, fontFamily: 'IconFont');
  static const IconData bad = IconData(0xe66f, fontFamily: 'IconFont');
  static const IconData arrowDoubleLeft = IconData(0xe670, fontFamily: 'IconFont');
  static const IconData arrowLeftCircle = IconData(0xe671, fontFamily: 'IconFont');
  static const IconData arrowDoubleRight = IconData(0xe672, fontFamily: 'IconFont');
  static const IconData camera = IconData(0xe673, fontFamily: 'IconFont');
  static const IconData chartBar = IconData(0xe674, fontFamily: 'IconFont');
  static const IconData attachment = IconData(0xe675, fontFamily: 'IconFont');
  static const IconData code = IconData(0xe676, fontFamily: 'IconFont');
  static const IconData close = IconData(0xe677, fontFamily: 'IconFont');
  static const IconData checkItem = IconData(0xe678, fontFamily: 'IconFont');
  static const IconData calendar = IconData(0xe679, fontFamily: 'IconFont');
  static const IconData comment = IconData(0xe67a, fontFamily: 'IconFont');
  static const IconData complete = IconData(0xe67b, fontFamily: 'IconFont');
  static const IconData chartPie = IconData(0xe67c, fontFamily: 'IconFont');
  static const IconData cry = IconData(0xe67d, fontFamily: 'IconFont');
  static const IconData customerService = IconData(0xe67e, fontFamily: 'IconFont');
  static const IconData delete = IconData(0xe67f, fontFamily: 'IconFont');
  static const IconData directionDown = IconData(0xe680, fontFamily: 'IconFont');
  static const IconData copy = IconData(0xe681, fontFamily: 'IconFont');
  static const IconData cut = IconData(0xe682, fontFamily: 'IconFont');
  static const IconData dataView = IconData(0xe683, fontFamily: 'IconFont');
  static const IconData directionDownCircle = IconData(0xe684, fontFamily: 'IconFont');
  static const IconData cirectionRight = IconData(0xe685, fontFamily: 'IconFont');
  static const IconData directionUp = IconData(0xe686, fontFamily: 'IconFont');
  static const IconData discount = IconData(0xe687, fontFamily: 'IconFont');
  static const IconData directionLeft = IconData(0xe688, fontFamily: 'IconFont');
  static const IconData download = IconData(0xe689, fontFamily: 'IconFont');
  static const IconData electronics = IconData(0xe68a, fontFamily: 'IconFont');
  static const IconData elipsis = IconData(0xe68b, fontFamily: 'IconFont');
  static const IconData export = IconData(0xe68c, fontFamily: 'IconFont');
  static const IconData explain = IconData(0xe68d, fontFamily: 'IconFont');
  static const IconData edit = IconData(0xe68e, fontFamily: 'IconFont');
  static const IconData eyeClose = IconData(0xe68f, fontFamily: 'IconFont');
  static const IconData email = IconData(0xe690, fontFamily: 'IconFont');
  static const IconData error = IconData(0xe691, fontFamily: 'IconFont');
  static const IconData eavorite = IconData(0xe692, fontFamily: 'IconFont');
  static const IconData fileCommon = IconData(0xe693, fontFamily: 'IconFont');
  static const IconData film = IconData(0xe694, fontFamily: 'IconFont');
  static const IconData fabulous = IconData(0xe695, fontFamily: 'IconFont');
  static const IconData file = IconData(0xe696, fontFamily: 'IconFont');
  static const IconData folderClose = IconData(0xe697, fontFamily: 'IconFont');
  static const IconData filter = IconData(0xe698, fontFamily: 'IconFont');
  static const IconData good = IconData(0xe699, fontFamily: 'IconFont');
  static const IconData hide = IconData(0xe69a, fontFamily: 'IconFont');
  static const IconData home = IconData(0xe69b, fontFamily: 'IconFont');
  static const IconData history = IconData(0xe69c, fontFamily: 'IconFont');
  static const IconData fileOpen = IconData(0xe69d, fontFamily: 'IconFont');
  static const IconData forward = IconData(0xe69e, fontFamily: 'IconFont');
  static const IconData imageText = IconData(0xe69f, fontFamily: 'IconFont');
  static const IconData link = IconData(0xe6a0, fontFamily: 'IconFont');
  static const IconData fullscreenShrink = IconData(0xe6a1, fontFamily: 'IconFont');
  static const IconData layers = IconData(0xe6a2, fontFamily: 'IconFont');
  static const IconData lock = IconData(0xe6a3, fontFamily: 'IconFont');
  static const IconData fullscreenExpand = IconData(0xe6a4, fontFamily: 'IconFont');
  static const IconData map = IconData(0xe6a5, fontFamily: 'IconFont');
  static const IconData meh = IconData(0xe6a6, fontFamily: 'IconFont');
  static const IconData menu = IconData(0xe6a7, fontFamily: 'IconFont');
  static const IconData loading = IconData(0xe6a8, fontFamily: 'IconFont');
  static const IconData help = IconData(0xe6a9, fontFamily: 'IconFont');
  static const IconData minusCircle = IconData(0xe6aa, fontFamily: 'IconFont');
  static const IconData modular = IconData(0xe6ab, fontFamily: 'IconFont');
  static const IconData notification = IconData(0xe6ac, fontFamily: 'IconFont');
  static const IconData mic = IconData(0xe6ad, fontFamily: 'IconFont');
}

==> desktop_ui-0.0.5.tar.gz: lib/components/icon.dart <==
// 自定义图标
import 'package:desktop_ui/constants.dart';
import 'package:flutter/material.dart';

/// 自定义图标-self desktop icon
class EasyIcon extends StatelessWidget {
  const EasyIcon(
    this.icon, {
    Key? key,
    this.color = iBlack,
    this.size,
    this.opacity,
    this.semanticLabel,
  }) : super(key: key);

  /// 图标
  final IconData? icon;

  /// 图标大小，默认为：20.0
  final double? size;

  /// 图标透明度，默认为：1.0
  final double? opacity;

  /// 图标颜色
  final Color? color;

  /// 图标语义描述信息，无障碍信息
  final String? semanticLabel;

  @override
  Widget build(BuildContext context) {
    final double? iconSize = size ?? iIconSize;
    // 不存在，返回固定大小的一块区域
    if (icon == null) {
      return Semantics(
        label: semanticLabel,
        child: SizedBox(width: iconSize, height: iconSize),
      );
    }
    final double iconOpacity = opacity ?? 1.0;
    Color iconColor = color ?? iBlack;
    if (iconOpacity != 1.0) {
      iconColor = iconColor.withOpacity(iconColor.opacity * iconOpacity);
    }

    Widget iconWidget = RichText(
      overflow: TextOverflow.visible,
      text: TextSpan(
        text: String.fromCharCode(icon!.codePoint),
        style: TextStyle(
          inherit: false,
          color: iconColor,
          fontSize: iconSize,
          fontFamily: icon!.fontFamily,
          package: 'desktop_ui',
        ),
      ),
    );

    return Semantics(
      label: semanticLabel,
      child: ExcludeSemantics(
        child: IntrinsicWidth(
          child: IntrinsicHeight(
            child: Center(
              child: iconWidget,
            ),
          ),
        ),
      ),
    );
  }
}

/// 支持的图标-support icon
class EasyIconData {
  static const IconData more = IconData(0xe6ae, fontFamily: 'IconFont');
  static const IconData pad = IconData(0xe6af, fontFamily: 'IconFont');
  static const IconData operation = IconData(0xe6b0, fontFamily: 'IconFont');
  static const IconData play = IconData(0xe6b1, fontFamily: 'IconFont');
  static const IconData print = IconData(0xe6b2, fontFamily: 'IconFont');
  static const IconData mobilePhone = IconData(0xe6b3, fontFamily: 'IconFont');
  static const IconData minus = IconData(0xe6b4, fontFamily: 'IconFont');
  static const IconData navigation = IconData(0xe6b5, fontFamily: 'IconFont');
  static const IconData pdf = IconData(0xe6b6, fontFamily: 'IconFont');
  static const IconData prompt = IconData(0xe6b7, fontFamily: 'IconFont');
  static const IconData move = IconData(0xe6b8, fontFamily: 'IconFont');
  static const IconData refresh = IconData(0xe6b9, fontFamily: 'IconFont');
  static const IconData picture = IconData(0xe6ba, fontFamily: 'IconFont');
  static const IconData pin = IconData(0xe6bb, fontFamily: 'IconFont');
  static const IconData save = IconData(0xe6bc, fontFamily: 'IconFont');
  static const IconData search = IconData(0xe6bd, fontFamily: 'IconFont');
  static const IconData share = IconData(0xe6be, fontFamily: 'IconFont');
  static const IconData scanning = IconData(0xe6bf, fontFamily: 'IconFont');
  static const IconData security = IconData(0xe6c0, fontFamily: 'IconFont');
  static const IconData signOut = IconData(0xe6c1, fontFamily: 'IconFont');
  static const IconData select = IconData(0xe6c2, fontFamily: 'IconFont');
  static const IconData stop = IconData(0xe6c3, fontFamily: 'IconFont');
  static const IconData success = IconData(0xe6c4, fontFamily: 'IconFont');
  static const IconData smile = IconData(0xe6c5, fontFamily: 'IconFont');
  static const IconData switchAction = IconData(0xe6c6, fontFamily: 'IconFont');
  static const IconData setting = IconData(0xe6c7, fontFamily: 'IconFont');
  static const IconData survey = IconData(0xe6c8, fontFamily: 'IconFont');
  static const IconData task = IconData(0xe6c9, fontFamily: 'IconFont');
  static const IconData skip = IconData(0xe6ca, fontFamily: 'IconFont');
  static const IconData text = IconData(0xe6cb, fontFamily: 'IconFont');
  static const IconData time = IconData(0xe6cc, fontFamily: 'IconFont');
  static const IconData telephoneOut = IconData(0xe6cd, fontFamily: 'IconFont');
  static const IconData toggleLeft = IconData(0xe6ce, fontFamily: 'IconFont');
  static const IconData toggleRight = IconData(0xe6cf, fontFamily: 'IconFont');
  static const IconData telephone = IconData(0xe6d0, fontFamily: 'IconFont');
  static const IconData top = IconData(0xe6d1, fontFamily: 'IconFont');
  static const IconData unlock = IconData(0xe6d2, fontFamily: 'IconFont');
  static const IconData user = IconData(0xe6d3, fontFamily: 'IconFont');
  static const IconData upload = IconData(0xe6d4, fontFamily: 'IconFont');
  static const IconData work = IconData(0xe6d5, fontFamily: 'IconFont');
  static const IconData training = IconData(0xe6d6, fontFamily: 'IconFont');
  static const IconData warning = IconData(0xe6d7, fontFamily: 'IconFont');
  static const IconData zoomIn = IconData(0xe6d8, fontFamily: 'IconFont');
  static const IconData zoomOut = IconData(0xe6d9, fontFamily: 'IconFont');
  static const IconData addBold = IconData(0xe6da, fontFamily: 'IconFont');
  static const IconData arrowLeftBold = IconData(0xe6db, fontFamily: 'IconFont');
  static const IconData arrowUpBold = IconData(0xe6dc, fontFamily: 'IconFont');
  static const IconData closeBold = IconData(0xe6dd, fontFamily: 'IconFont');
  static const IconData arrowDownBold = IconData(0xe6de, fontFamily: 'IconFont');
  static const IconData minusBold = IconData(0xe6df, fontFamily: 'IconFont');
  static const IconData arrowRightBold = IconData(0xe6e0, fontFamily: 'IconFont');
  static const IconData selectBold = IconData(0xe6e1, fontFamily: 'IconFont');
  static const IconData add = IconData(0xe664, fontFamily: 'IconFont');
  static const IconData addCircle = IconData(0xe665, fontFamily: 'IconFont');
  static const IconData adjust = IconData(0xe666, fontFamily: 'IconFont');
  static const IconData arrowUpCircle = IconData(0xe667, fontFamily: 'IconFont');
  static const IconData arrowRightCircle = IconData(0xe668, fontFamily: 'IconFont');
  static const IconData arrowDown = IconData(0xe669, fontFamily: 'IconFont');
  static const IconData ashbin = IconData(0xe66a, fontFamily: 'IconFont');
  static const IconData arrowRight = IconData(0xe66b, fontFamily: 'IconFont');
  static const IconData browse = IconData(0xe66c, fontFamily: 'IconFont');
  static const IconData bottom = IconData(0xe66d, fontFamily: 'IconFont');
  static const IconData back = IconData(0xe66e, fontFamily: 'IconFont');
  static const IconData bad = IconData(0xe66f, fontFamily: 'IconFont');
  static const IconData arrowDoubleLeft = IconData(0xe670, fontFamily: 'IconFont');
  static const IconData arrowLeftCircle = IconData(0xe671, fontFamily: 'IconFont');
  static const IconData arrowDoubleRight = IconData(0xe672, fontFamily: 'IconFont');
  static const IconData camera = IconData(0xe673, fontFamily: 'IconFont');
  static const IconData chartBar = IconData(0xe674, fontFamily: 'IconFont');
  static const IconData attachment = IconData(0xe675, fontFamily: 'IconFont');
  static const IconData code = IconData(0xe676, fontFamily: 'IconFont');
  static const IconData close = IconData(0xe677, fontFamily: 'IconFont');
  static const IconData checkItem = IconData(0xe678, fontFamily: 'IconFont');
  static const IconData calendar = IconData(0xe679, fontFamily: 'IconFont');
  static const IconData comment = IconData(0xe67a, fontFamily: 'IconFont');
  static const IconData complete = IconData(0xe67b, fontFamily: 'IconFont');
  static const IconData chartPie = IconData(0xe67c, fontFamily: 'IconFont');
  static const IconData cry = IconData(0xe67d, fontFamily: 'IconFont');
  static const IconData customerService = IconData(0xe67e, fontFamily: 'IconFont');
  static const IconData delete = IconData(0xe67f, fontFamily: 'IconFont');
  static const IconData directionDown = IconData(0xe680, fontFamily: 'IconFont');
  static const IconData copy = IconData(0xe681, fontFamily: 'IconFont');
  static const IconData cut = IconData(0xe682, fontFamily: 'IconFont');
  static const IconData dataView = IconData(0xe683, fontFamily: 'IconFont');
  static const IconData directionDownCircle = IconData(0xe684, fontFamily: 'IconFont');
  static const IconData cirectionRight = IconData(0xe685, fontFamily: 'IconFont');
  static const IconData directionUp = IconData(0xe686, fontFamily: 'IconFont');
  static const IconData discount = IconData(0xe687, fontFamily: 'IconFont');
  static const IconData directionLeft = IconData(0xe688, fontFamily: 'IconFont');
  static const IconData download = IconData(0xe689, fontFamily: 'IconFont');
  static const IconData electronics = IconData(0xe68a, fontFamily: 'IconFont');
  static const IconData elipsis = IconData(0xe68b, fontFamily: 'IconFont');
  static const IconData export = IconData(0xe68c, fontFamily: 'IconFont');
  static const IconData explain = IconData(0xe68d, fontFamily: 'IconFont');
  static const IconData edit = IconData(0xe68e, fontFamily: 'IconFont');
  static const IconData eyeClose = IconData(0xe68f, fontFamily: 'IconFont');
  static const IconData email = IconData(0xe690, fontFamily: 'IconFont');
  static const IconData error = IconData(0xe691, fontFamily: 'IconFont');
  static const IconData favorite = IconData(0xe692, fontFamily: 'IconFont');
  static const IconData fileCommon = IconData(0xe693, fontFamily: 'IconFont');
  static const IconData film = IconData(0xe694, fontFamily: 'IconFont');
  static const IconData fabulous = IconData(0xe695, fontFamily: 'IconFont');
  static const IconData file = IconData(0xe696, fontFamily: 'IconFont');
  static const IconData folderClose = IconData(0xe697, fontFamily: 'IconFont');
  static const IconData filter = IconData(0xe698, fontFamily: 'IconFont');
  static const IconData good = IconData(0xe699, fontFamily: 'IconFont');
  static const IconData hide = IconData(0xe69a, fontFamily: 'IconFont');
  static const IconData home = IconData(0xe69b, fontFamily: 'IconFont');
  static const IconData history = IconData(0xe69c, fontFamily: 'IconFont');
  static const IconData fileOpen = IconData(0xe69d, fontFamily: 'IconFont');
  static const IconData forward = IconData(0xe69e, fontFamily: 'IconFont');
  static const IconData imageText = IconData(0xe69f, fontFamily: 'IconFont');
  static const IconData link = IconData(0xe6a0, fontFamily: 'IconFont');
  static const IconData fullscreenShrink = IconData(0xe6a1, fontFamily: 'IconFont');
  static const IconData layers = IconData(0xe6a2, fontFamily: 'IconFont');
  static const IconData lock = IconData(0xe6a3, fontFamily: 'IconFont');
  static const IconData fullscreenExpand = IconData(0xe6a4, fontFamily: 'IconFont');
  static const IconData map = IconData(0xe6a5, fontFamily: 'IconFont');
  static const IconData meh = IconData(0xe6a6, fontFamily: 'IconFont');
  static const IconData menu = IconData(0xe6a7, fontFamily: 'IconFont');
  static const IconData loading = IconData(0xe6a8, fontFamily: 'IconFont');
  static const IconData help = IconData(0xe6a9, fontFamily: 'IconFont');
  static const IconData minusCircle = IconData(0xe6aa, fontFamily: 'IconFont');
  static const IconData modular = IconData(0xe6ab, fontFamily: 'IconFont');
  static const IconData notification = IconData(0xe6ac, fontFamily: 'IconFont');
  static const IconData mic = IconData(0xe6ad, fontFamily: 'IconFont');
}
